==> simplepycons-1!13.9.0-py3-none-any.whl: simplepycons/_cocacola.py <==
#
# SPDX-License-Identifier: MIT
#
# Copyright (c) 2024 Carsten Igel.
#
# This file is part of simplepycons
# (see https://github.com/carstencodes/simplepycons).
#
# This file is published using the MIT license.
# Refer to LICENSE for more information
#
""""""
# pylint: disable=C0302
# Justification: Code is generated

from typing import TYPE_CHECKING

from .base_icon import Icon

if TYPE_CHECKING:
    from collections.abc import Iterable


class CocaColaIcon(Icon):
    """"""
    @property
    def name(self) -> "str":
        return "cocacola"

    @property
    def original_file_name(self) -> "str":
        return "cocacola.svg"

    @property
    def title(self) -> "str":
        return "Coca Cola"

    @property
    def primary_color(self) -> "str":
        return "#D00013"

    @property
    def raw_svg(self) -> "str":
        return ''' <svg xmlns="http://www.w3.org/2000/svg"
 role="img" viewBox="0 0 24 24">
    <title>Coca Cola</title>
     <path d="M16.813 8.814s-.45.18-.973.756c-.524.577-.828 1.225-.603
 1.397.087.066.287.079.65-.25a2.864 2.864 0 0 0
 .766-1.063c.234-.57.16-.833.16-.84m2.863
 1.038c-.581-.299-1.006-.664-1.448-.89-.422-.216-.695-.307-1.036-.261a1.057
 1.057 0 0 0-.14.035s.176.6-.523 1.607c-.708 1.022-1.35
 1.015-1.533.734-.191-.296.056-.9.468-1.437.432-.562 1.19-1.028
 1.19-1.028s-.241-.148-.835.19c-.58.326-1.577 1.107-2.502 2.423-.926
 1.316-1.11 2.04-1.242 2.61-.132.57-.012 1.18.62 1.18s1.368-.964
 1.576-1.299c.386-.624.637-1.581.112-1.45-.259.065-.468.351-.6.627a2.683
 2.683 0 0 0-.19.554 2.185 2.185 0 0 0-.513.298 3.788 3.788 0 0
 0-.486.43s.002-.456.365-1.194c.364-.737 1.03-1.074
 1.408-1.106.34-.027.783.262.408 1.327-.375 1.065-1.483 2.36-2.646
 2.376-1.073.015-1.776-1.355-.282-3.745C13.501 9.19 15.441 8.38 16.07
 8.29c.63-.09.835.187.835.187a2.709 2.709 0 0 1 1.197-.197c.77.052
 1.364.596
 2.15.979-.205.195-.4.4-.575.592m3.454-.89c-.533.342-1.27.652-1.979.586-.179.185-.371.4-.563.634
 1.228.243 2.305-.519 2.877-1.167A3.82 3.82 0 0 0 24 8.248a4.792 4.792
 0 0 1-.869.714m-1.636 3.462a.268.268 0 0 0 .023-.051.124.124 0 0
 0-.113-.108c-.117-.005-.277.017-.695.48a6.303 6.303 0 0 0-.89
 1.263c-.24.438-.337.764-.2.848a.199.199 0 0 0
 .146.015c.093-.022.199-.11.36-.295.075-.088.158-.212.258-.349.277-.376.973-1.563
 1.111-1.803m-4.349.504c.07-.182.159-.541-.026-.682-.199-.15-.705.201-.708.561-.003.369.357.535.443.559.05.013.066.01.09-.029a3.284
 3.284 0 0 0 .201-.409m-.383.67a1.531 1.531 0 0 1-.348-.222 1.116
 1.116 0 0
 1-.26-.317c-.008-.012-.015-.003-.023.008-.007.01-.039.039-.309.434-.27.396-.684
 1.216-.31 1.355.241.09.641-.331.86-.61a5.21 5.21 0 0 0
 .402-.614c.012-.023
 0-.029-.012-.034m4.258.947c-.102.163-.218.476.117.281.41-.236.994-1.123.994-1.123h.265a8.88
 8.88 0 0 1-.803
 1.054c-.415.46-.922.879-1.28.837-.416-.048-.286-.596-.286-.596s-.596.635-1.01.59c-.557-.062-.387-.751-.387-.751s-.63.774-1.06.75c-.673-.04-.504-.859-.316-1.436.1-.308.193-.55.193-.55s-.067.017-.21.038c-.076.011-.212.019-.212.019s-.28.495-.505.792c-.224.297-1.178
 1.322-1.74 1.117-.518-.19-.346-.984-.044-1.615.44-.92 1.68-2.243
 2.396-2.068.741.18.017 1.532.017 1.532s0
 .005.007.009c.015.005.054.01.143-.008a1.605 1.605 0 0 0
 .271-.08s.746-1.561 1.569-2.583c.823-1.02 2.465-2.78
 3.11-2.354.156.105.086.465-.126.902a2.891 2.891 0 0
 1-.291.078c.142-.258.236-.475.264-.627.097-.528-1.135.585-2.015
 1.78a16.594 16.594 0 0 0-1.409 2.28 3.86 3.86 0 0 0 .454-.324 13.002
 13.002 0 0 0 1.118-1.043 12.169 12.169 0 0 0 .951-1.098 2.58 2.58 0 0
 0 .28-.029 12.054 12.054 0 0 1-1.05 1.24c-.35.355-.73.737-1.061
 1.015a8.84 8.84 0 0 1-.931.691s-.77 1.553-.351
 1.652c.246.06.732-.69.732-.69s.635-.967 1.017-1.404c.522-.593.97-.936
 1.42-.942.261-.005.415.273.415.273l.123-.19h.757s-1.414 2.398-1.527
 2.579m2.111-5.58c-.533.341-1.27.651-1.979.585-.18.185-.371.4-.564.634
 1.229.243 2.305-.518 2.878-1.167A3.82 3.82 0 0 0 24 8.248a4.792 4.792
 0 0 1-.869.714m-10.63 1.177h-.72l-.407.658h.72zm-3.41 2.277c.307-.42
 1.152-1.891 1.152-1.891a.124.124 0 0
 0-.112-.108c-.117-.006-.312.034-.7.519-.387.485-.688.87-.907
 1.272-.24.438-.346.747-.207.831a.205.205 0 0 0
 .144.015c.09-.022.208-.113.369-.298a5.57 5.57 0 0 0
 .262-.34m-3.863-1.99c-.199-.15-.705.201-.708.56-.003.369.456.482.515.484a.09.09
 0 0 0 .05-.01.06.06 0 0 0 .024-.027 3.483 3.483 0 0 0
 .146-.325c.07-.183.158-.541-.027-.682m-.3 1.27a1.678 1.678 0 0
 1-.39-.18.812.812 0 0
 1-.279-.309c-.007-.012-.015-.003-.022.008-.007.01-.047.061-.318.458-.27.398-.672
 1.21-.296 1.35.24.09.644-.334.864-.612a7.24 7.24 0 0 0
 .455-.681c.009-.024 0-.03-.014-.034m5.88.244h.263s-1.321 1.912-2.068
 1.823c-.416-.049-.293-.563-.293-.563s-.585.685-1.123.546c-.487-.125-.172-.936-.172-.936-.056.022-1.111
 1.211-1.853.926-.776-.3-.373-1.296-.225-1.595.125-.253.263-.499.263-.499s-.119.034-.195.051l-.186.04s-.367.596-.591.894c-.225.297-1.178
 1.32-1.74 1.117-.562-.204-.423-.99-.107-1.615.512-1.012 1.726-2.256
 2.458-2.068.739.189.127 1.388.127 1.388s.147.019.5-.222c.507-.346
 1.176-1.277 1.901-1.167.342.051.66.4.225
 1.064-.139.213-.372.403-.55.215-.111-.118-.014-.33.103-.477a.457.457
 0 0 1 .39-.179s.12-.273-.185-.269c-.247.005-.871.58-1.223
 1.16-.323.533-.813 1.441-.322 1.639.451.182 1.309-.836
 1.706-1.37.397-.533 1.302-1.742
 2.062-1.79.261-.017.417.221.417.221l.088-.139h.759s-1.43 2.387-1.542
 2.567c-.088.141-.204.46.117.281.322-.178.996-1.043.996-1.043m-.414
 3.824a3.144 3.144 0 0 0-1.908-.557 1.17 1.17 0 0
 0-.93.504c-.29-.505-.862-.815-1.747-.808-1.43.016-2.849.676-3.972.675-1.077
 0-1.863-.677-1.837-1.88.047-2.109 1.83-4.009 3.16-4.864.767-.49
 1.409-.637
 1.828-.59.306.034.674.388.442.909-.341.761-.812.699-.795.335.01-.237.168-.386.286-.469a.582.582
 0 0 1 .278-.068c.068-.057.117-.474-.429-.337-.546.137-1.21.676-1.84
 1.371-.63.696-1.61 2.011-1.852 3.392-.113.64-.039 1.808 1.48 1.795
 1.287-.01 3.185-.859 4.929-.841a3.34 3.34 0 0 1
 1.725.472c.451.278.992.684 1.184.961" />
</svg>'''

    @property
    def guidelines_url(self) -> "str | None":
        _value: "str" = ''''''
        if len(_value) > 0:
            return _value
        return None

    @property
    def source(self) -> "str":
        return '''https://upload.wikimedia.org/wikipedia/common'''

    @property
    def license(self) -> "tuple[str | None, str | None]":
        _type: "str | None" = ''''''
        _url: "str | None" = ''''''

        if _type is not None and len(_type) == 0:
            _type = None

        if _url is not None and len(_url) == 0:
            _url = None

        return _type, _url

    @property
    def aliases(self) -> "Iterable[str]":
        yield from []

==> simplepycons-1!13.14.1-py3-none-any.whl: simplepycons/_cocacola.py <==
#
# SPDX-License-Identifier: MIT
#
# Copyright (c) 2024 Carsten Igel.
#
# This file is part of simplepycons
# (see https://github.com/carstencodes/simplepycons).
#
# This file is published using the MIT license.
# Refer to LICENSE for more information
#
""""""
# pylint: disable=C0302
# Justification: Code is generated

from typing import TYPE_CHECKING

from .base_icon import Icon

if TYPE_CHECKING:
    from collections.abc import Iterable


class CocaColaIcon(Icon):
    """"""
    @property
    def name(self) -> "str":
        return "cocacola"

    @property
    def original_file_name(self) -> "str":
        return "cocacola.svg"

    @property
    def title(self) -> "str":
        return "Coca Cola"

    @property
    def primary_color(self) -> "str":
        return "#D00013"

    @property
    def raw_svg(self) -> "str":
        return ''' <svg xmlns="http://www.w3.org/2000/svg"
 role="img" viewBox="0 0 24 24">
    <title>Coca Cola</title>
     <path d="M16.813 8.814s-.45.18-.973.756c-.524.577-.828 1.225-.603
 1.397.087.066.287.079.65-.25a2.864 2.864 0 0 0
 .766-1.063c.234-.57.16-.833.16-.84m2.863
 1.038c-.581-.299-1.006-.664-1.448-.89-.422-.216-.695-.307-1.036-.261a1.057
 1.057 0 0 0-.14.035s.176.6-.523 1.607c-.708 1.022-1.35
 1.015-1.533.734-.191-.296.056-.9.468-1.437.432-.562 1.19-1.028
 1.19-1.028s-.241-.148-.835.19c-.58.326-1.577 1.107-2.502 2.423-.926
 1.316-1.11 2.04-1.242 2.61-.132.57-.012 1.18.62 1.18s1.368-.964
 1.576-1.299c.386-.624.637-1.581.112-1.45-.259.065-.468.351-.6.627a2.683
 2.683 0 0 0-.19.554 2.185 2.185 0 0 0-.513.298 3.788 3.788 0 0
 0-.486.43s.002-.456.365-1.194c.364-.737 1.03-1.074
 1.408-1.106.34-.027.783.262.408 1.327-.375 1.065-1.483 2.36-2.646
 2.376-1.073.015-1.776-1.355-.282-3.745C13.501 9.19 15.441 8.38 16.07
 8.29c.63-.09.835.187.835.187a2.709 2.709 0 0 1 1.197-.197c.77.052
 1.364.596
 2.15.979-.205.195-.4.4-.575.592m3.454-.89c-.533.342-1.27.652-1.979.586-.179.185-.371.4-.563.634
 1.228.243 2.305-.519 2.877-1.167A3.82 3.82 0 0 0 24 8.248a4.792 4.792
 0 0 1-.869.714m-1.636 3.462a.268.268 0 0 0 .023-.051.124.124 0 0
 0-.113-.108c-.117-.005-.277.017-.695.48a6.303 6.303 0 0 0-.89
 1.263c-.24.438-.337.764-.2.848a.199.199 0 0 0
 .146.015c.093-.022.199-.11.36-.295.075-.088.158-.212.258-.349.277-.376.973-1.563
 1.111-1.803m-4.349.504c.07-.182.159-.541-.026-.682-.199-.15-.705.201-.708.561-.003.369.357.535.443.559.05.013.066.01.09-.029a3.284
 3.284 0 0 0 .201-.409m-.383.67a1.531 1.531 0 0 1-.348-.222 1.116
 1.116 0 0
 1-.26-.317c-.008-.012-.015-.003-.023.008-.007.01-.039.039-.309.434-.27.396-.684
 1.216-.31 1.355.241.09.641-.331.86-.61a5.21 5.21 0 0 0
 .402-.614c.012-.023
 0-.029-.012-.034m4.258.947c-.102.163-.218.476.117.281.41-.236.994-1.123.994-1.123h.265a8.88
 8.88 0 0 1-.803
 1.054c-.415.46-.922.879-1.28.837-.416-.048-.286-.596-.286-.596s-.596.635-1.01.59c-.557-.062-.387-.751-.387-.751s-.63.774-1.06.75c-.673-.04-.504-.859-.316-1.436.1-.308.193-.55.193-.55s-.067.017-.21.038c-.076.011-.212.019-.212.019s-.28.495-.505.792c-.224.297-1.178
 1.322-1.74 1.117-.518-.19-.346-.984-.044-1.615.44-.92 1.68-2.243
 2.396-2.068.741.18.017 1.532.017 1.532s0
 .005.007.009c.015.005.054.01.143-.008a1.605 1.605 0 0 0
 .271-.08s.746-1.561 1.569-2.583c.823-1.02 2.465-2.78
 3.11-2.354.156.105.086.465-.126.902a2.891 2.891 0 0
 1-.291.078c.142-.258.236-.475.264-.627.097-.528-1.135.585-2.015
 1.78a16.594 16.594 0 0 0-1.409 2.28 3.86 3.86 0 0 0 .454-.324 13.002
 13.002 0 0 0 1.118-1.043 12.169 12.169 0 0 0 .951-1.098 2.58 2.58 0 0
 0 .28-.029 12.054 12.054 0 0 1-1.05 1.24c-.35.355-.73.737-1.061
 1.015a8.84 8.84 0 0 1-.931.691s-.77 1.553-.351
 1.652c.246.06.732-.69.732-.69s.635-.967 1.017-1.404c.522-.593.97-.936
 1.42-.942.261-.005.415.273.415.273l.123-.19h.757s-1.414 2.398-1.527
 2.579m2.111-5.58c-.533.341-1.27.651-1.979.585-.18.185-.371.4-.564.634
 1.229.243 2.305-.518 2.878-1.167A3.82 3.82 0 0 0 24 8.248a4.792 4.792
 0 0 1-.869.714m-10.63 1.177h-.72l-.407.658h.72zm-3.41 2.277c.307-.42
 1.152-1.891 1.152-1.891a.124.124 0 0
 0-.112-.108c-.117-.006-.312.034-.7.519-.387.485-.688.87-.907
 1.272-.24.438-.346.747-.207.831a.205.205 0 0 0
 .144.015c.09-.022.208-.113.369-.298a5.57 5.57 0 0 0
 .262-.34m-3.863-1.99c-.199-.15-.705.201-.708.56-.003.369.456.482.515.484a.09.09
 0 0 0 .05-.01.06.06 0 0 0 .024-.027 3.483 3.483 0 0 0
 .146-.325c.07-.183.158-.541-.027-.682m-.3 1.27a1.678 1.678 0 0
 1-.39-.18.812.812 0 0
 1-.279-.309c-.007-.012-.015-.003-.022.008-.007.01-.047.061-.318.458-.27.398-.672
 1.21-.296 1.35.24.09.644-.334.864-.612a7.24 7.24 0 0 0
 .455-.681c.009-.024 0-.03-.014-.034m5.88.244h.263s-1.321 1.912-2.068
 1.823c-.416-.049-.293-.563-.293-.563s-.585.685-1.123.546c-.487-.125-.172-.936-.172-.936-.056.022-1.111
 1.211-1.853.926-.776-.3-.373-1.296-.225-1.595.125-.253.263-.499.263-.499s-.119.034-.195.051l-.186.04s-.367.596-.591.894c-.225.297-1.178
 1.32-1.74 1.117-.562-.204-.423-.99-.107-1.615.512-1.012 1.726-2.256
 2.458-2.068.739.189.127 1.388.127 1.388s.147.019.5-.222c.507-.346
 1.176-1.277 1.901-1.167.342.051.66.4.225
 1.064-.139.213-.372.403-.55.215-.111-.118-.014-.33.103-.477a.457.457
 0 0 1 .39-.179s.12-.273-.185-.269c-.247.005-.871.58-1.223
 1.16-.323.533-.813 1.441-.322 1.639.451.182 1.309-.836
 1.706-1.37.397-.533 1.302-1.742
 2.062-1.79.261-.017.417.221.417.221l.088-.139h.759s-1.43 2.387-1.542
 2.567c-.088.141-.204.46.117.281.322-.178.996-1.043.996-1.043m-.414
 3.824a3.144 3.144 0 0 0-1.908-.557 1.17 1.17 0 0
 0-.93.504c-.29-.505-.862-.815-1.747-.808-1.43.016-2.849.676-3.972.675-1.077
 0-1.863-.677-1.837-1.88.047-2.109 1.83-4.009 3.16-4.864.767-.49
 1.409-.637
 1.828-.59.306.034.674.388.442.909-.341.761-.812.699-.795.335.01-.237.168-.386.286-.469a.582.582
 0 0 1 .278-.068c.068-.057.117-.474-.429-.337-.546.137-1.21.676-1.84
 1.371-.63.696-1.61 2.011-1.852 3.392-.113.64-.039 1.808 1.48 1.795
 1.287-.01 3.185-.859 4.929-.841a3.34 3.34 0 0 1
 1.725.472c.451.278.992.684 1.184.961" />
</svg>'''

    @property
    def guidelines_url(self) -> "str | None":
        _value: "str" = ''''''
        if len(_value) > 0:
            return _value
        return None

    @property
    def source(self) -> "str":
        return '''https://commons.wikimedia.org/wiki/File:Coca-'''

    @property
    def license(self) -> "tuple[str | None, str | None]":
        _type: "str | None" = ''''''
        _url: "str | None" = ''''''

        if _type is not None and len(_type) == 0:
            _type = None

        if _url is not None and len(_url) == 0:
            _url = None

        return _type, _url

    @property
    def aliases(self) -> "Iterable[str]":
        yield from []
